#!/bin/bash

# battery-monitor.sh

# Once a user defined minimum is reached, this program lets the user know
# when the battery needs to be charged and suspends the computer.

# This program has been verified to work on a Debian 12 GNU/Linux x86_64
# default console installation, but the installation of the bc program is
# required.

# Copyright (c) 2024, Scott C. MacCallum (scott@scm-guru.live).

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# Change this variable to the group that should be informed of a need to
# charge the battery. On GNU/Linux distributions users are often part of
# a group that is the same as their login name, which works well if you only
# want your user to be informed on the console.

group="scm"

# Change the battery variable to your batteries identification.

battery="BAT0"

# Calculate the number of minutes that the battery has left.

charge=$(cat /sys/class/power_supply/$battery/charge_now)
discharge=$(cat /sys/class/power_supply/$battery/current_now)

# If the computer is plugged in, exit the program.

if (( discharge == 0 )); then
    exit 0
fi

hours=$(echo "scale=2; $charge / $discharge" | bc -l)
minutes=$(echo "scale=2; $hours * 60" | bc -l)

# Change the minimum variable to the minimum amount of minutes that a battery
# is estimated to have left before the group is informed to recharge it. When
# I tested this, I was surprised to discover that the computer turned off
# despite having reported that there was 10 minutes left! I created the
# battery-status.sh script to aid in my understanding of what was going on,
# and I discovered a variance of minutes plus/minus each time that I ran it,
# so the system is clearly making an estimate. Keep this in mind when setting
# the minimum value. Less than 40.00 is likely a bad idea. YOU'VE BEEN
# WARNED!

minimum=40.00

# If the minutes of charge are less than the minimum, suspend the computer.

if (( $(echo "$minutes < $minimum" | bc -l) )); then
    echo "Suspending the computer! Battery charge is needed!" | wall -g $group
    sleep 3
    systemctl suspend
fi

exit 0
